@@ -16,7 +16,6 @@ import json
 
 from oslo_log import log as logging
 from testtools import matchers
-import unittest
 
 from vitrage_tempest_plugin.tests.base import BaseVitrageTempest
 from vitrage_tempest_plugin.tests.base import IsEmpty
@@ -49,6 +48,7 @@ class TestResource(BaseVitrageTempest):
         cls.instances = nova_utils.create_instances(num_instances=1,
                                                     set_public_network=True)
 
+    # noinspection PyPep8Naming
     @classmethod
     def tearDownClass(cls):
         super(TestResource, cls).tearDownClass()
@@ -57,32 +57,26 @@ class TestResource(BaseVitrageTempest):
     @utils.tempest_logger
     def test_compare_cli_vs_api_resource_list(self):
         """resource list """
-        try:
-            api_resources = self.vitrage_client.resource.list(
-                all_tenants=True)
+        api_resources = self.vitrage_client.resource.list(
+            all_tenants=True)
 
-            LOG.info("api_resources = %s", api_resources)
+        LOG.info("api_resources = %s", api_resources)
 
-            cli_resources = utils.run_vitrage_command(
-                'vitrage resource list --all -f json', self.conf)
+        cli_resources = utils.run_vitrage_command(
+            'vitrage resource list --all -f json')
 
-            self._compare_resources(api_resources, cli_resources)
-        except Exception as e:
-            self._handle_exception(e)
-            raise
+        self._compare_resources(api_resources, cli_resources)
 
     @utils.tempest_logger
     def test_default_resource_list(self):
         """resource list with default query
 
-        get the resources: network, instance, port
+        get the resources: network, instance, port, zone, host, cluster
         """
-        try:
-            resources = self.vitrage_client.resource.list(all_tenants=False)
-            self.assertThat(resources, matchers.HasLength(3))
-        except Exception as e:
-            self._handle_exception(e)
-            raise
+        # TODO(e0ne): split this test to verify that only network,
+        # instance and port are returned to non-admin user.
+        resources = self.vitrage_client.resource.list(all_tenants=False)
+        self.assertThat(resources, matchers.HasLength(6))
 
     @utils.tempest_logger
     def test_resource_list_with_all_tenants(self):
@@ -100,9 +94,7 @@ class TestResource(BaseVitrageTempest):
             resources = self.vitrage_client.resource.list(all_tenants=True)
 
             self.assertEqual(len(resources_before) + 2, len(resources))
-        except Exception as e:
-            self._handle_exception(e)
-            raise
+
         finally:
             if instances:
                 nova_utils.delete_created_instances(instances)
@@ -113,105 +105,63 @@ class TestResource(BaseVitrageTempest):
 
         get the resource: one instance
         """
-        try:
-            resources = self.vitrage_client.resource.list(
-                resource_type=NOVA_INSTANCE_DATASOURCE,
-                all_tenants=True)
-            self.assertThat(resources, matchers.HasLength(1))
-        except Exception as e:
-            self._handle_exception(e)
-            raise
+        resources = self.vitrage_client.resource.list(
+            resource_type=NOVA_INSTANCE_DATASOURCE,
+            all_tenants=True)
+        self.assertThat(resources, matchers.HasLength(1))
 
     @utils.tempest_logger
     def test_resource_list_with_no_existing_type(self):
         """resource list with no existing type"""
-        try:
-            resources = self.vitrage_client.resource.list(
-                resource_type=CINDER_VOLUME_DATASOURCE,
-                all_tenants=True)
-            self.assertThat(resources, IsEmpty())
-        except Exception as e:
-            self._handle_exception(e)
-            raise
+        resources = self.vitrage_client.resource.list(
+            resource_type=CINDER_VOLUME_DATASOURCE,
+            all_tenants=True)
+        self.assertThat(resources, IsEmpty())
 
     @utils.tempest_logger
     def test_resource_list_with_query_existing(self):
-        try:
-            resources = self.vitrage_client.resource.list(
-                resource_type=NOVA_INSTANCE_DATASOURCE,
-                all_tenants=True,
-                query='{"==": {"name": "vm-0"}}'
-            )
-            self.assertThat(resources, matchers.HasLength(1))
-        except Exception as e:
-            self._handle_exception(e)
-            raise
+        resources = self.vitrage_client.resource.list(
+            resource_type=NOVA_INSTANCE_DATASOURCE,
+            all_tenants=True,
+            query='{"==": {"name": "vm-0"}}'
+        )
+        self.assertThat(resources, matchers.HasLength(1))
 
     @utils.tempest_logger
     def test_resource_list_with_query_none_existing(self):
-        try:
-            resources = self.vitrage_client.resource.list(
-                resource_type=NOVA_INSTANCE_DATASOURCE,
-                all_tenants=True,
-                query='{"==": {"name": "kuku-does-not-exist"}}'
-            )
-            self.assertThat(resources, matchers.HasLength(0))
-        except Exception as e:
-            self._handle_exception(e)
-            raise
+        resources = self.vitrage_client.resource.list(
+            resource_type=NOVA_INSTANCE_DATASOURCE,
+            all_tenants=True,
+            query='{"==": {"name": "kuku-does-not-exist"}}'
+        )
+        self.assertThat(resources, matchers.HasLength(0))
 
     @utils.tempest_logger
     def test_resource_count(self):
-        try:
-            resources = self.vitrage_client.resource.count(
-                resource_type=NOVA_INSTANCE_DATASOURCE,
-                all_tenants=True,
-                query='{"==": {"name": "vm-0"}}'
-            )
-            self.assertThat(resources, matchers.HasLength(1))
-            self.assertEqual(1, resources[NOVA_INSTANCE_DATASOURCE])
-        except Exception as e:
-            self._handle_exception(e)
-            raise
+        resources = self.vitrage_client.resource.count(
+            resource_type=NOVA_INSTANCE_DATASOURCE,
+            all_tenants=True,
+            query='{"==": {"name": "vm-0"}}'
+        )
+        self.assertThat(resources, matchers.HasLength(1))
+        self.assertEqual(1, resources[NOVA_INSTANCE_DATASOURCE])
 
     @utils.tempest_logger
     def test_resource_count_empty(self):
-        try:
-            resources = self.vitrage_client.resource.count(
-                resource_type=NOVA_INSTANCE_DATASOURCE,
-                all_tenants=True,
-                query='{"==": {"name": "kuku-does-not-exist"}}'
-            )
-            self.assertThat(resources, matchers.HasLength(0))
-        except Exception as e:
-            self._handle_exception(e)
-            raise
-
-    @unittest.skip("CLI tests are ineffective and not maintained")
-    def test_compare_resource_show(self):
-        """resource_show test"""
-        resource_list = self.vitrage_client.resource.list(all_tenants=False)
-        self.self.assertThat(resource_list, IsNotEmpty())
-        for resource in resource_list:
-            api_resource_show = \
-                self.vitrage_client.resource.get(resource[VProps.VITRAGE_ID])
-            cli_resource_show = utils.run_vitrage_command(
-                'vitrage resource show ' + resource[VProps.VITRAGE_ID],
-                self.conf)
-
-            self._compare_resource_show(
-                api_resource_show, cli_resource_show)
+        resources = self.vitrage_client.resource.count(
+            resource_type=NOVA_INSTANCE_DATASOURCE,
+            all_tenants=True,
+            query='{"==": {"name": "kuku-does-not-exist"}}'
+        )
+        self.assertThat(resources, matchers.HasLength(0))
 
     def test_resource_show_with_no_existing_resource(self):
         """resource_show test no existing resource"""
         try:
 
             self.assertRaises(ClientException,
-                              self.vitrage_client.resource.get(
-                                  'test_for_no_existing'))
-        except Exception as e:
-            self._handle_exception(e)
-
+                              self.vitrage_client.resource.get,
+                              'test_for_no_existing')
         finally:
             nova_utils.delete_all_instances()
 
@@ -250,14 +200,3 @@ class TestResource(BaseVitrageTempest):
                 self.assertEqual(
                     cli_resource.get("State").lower(),
                     api_resource.get(VProps.VITRAGE_OPERATIONAL_STATE).lower())
-
-    def _compare_resource_show(self, api_resource_show,
-                               cli_resource_show):
-        self.assertIsNotNone(api_resource_show,
-                             'The resource show taken from rest api is empty')
-        self.assertIsNotNone(cli_resource_show,
-                             'The resource show taken from terminal is empty')
-
-        for item in self.properties:
-            self.assertEqual(api_resource_show.get(item),
-                             cli_resource_show.get(item))
